pub(crate) struct Opts {Show 13 fields
pub(crate) exit_dump_len: u32,
pub(crate) slice_us: u64,
pub(crate) slice_us_lag: u64,
pub(crate) cpu_busy_thresh: u64,
pub(crate) polling_ms: u64,
pub(crate) primary_domain: Option<String>,
pub(crate) preferred_idle_scan: bool,
pub(crate) stats: Option<f64>,
pub(crate) monitor: Option<f64>,
pub(crate) verbose: bool,
pub(crate) version: bool,
pub(crate) help_stats: bool,
pub libbpf: LibbpfOpts,
}Fields
exit_dump_len: u32Exit debug dump buffer length. 0 indicates default.
slice_us: u64Maximum scheduling slice duration in microseconds.
slice_us_lag: u64Maximum time slice lag in microseconds.
A positive value can help to enhance the responsiveness of interactive tasks, but it can also make performance more “spikey”.
cpu_busy_thresh: u64CPU busy threshold.
Specifies the CPU utilization percentage (0-100%) at which the scheduler considers the system to be busy.
polling_ms: u64Polling time (ms) to refresh the CPU utilization.
This interval determines how often the scheduler refreshes the CPU utilization that is compared with the CPU busy threshold (option -c) to decide if the system is busy or not.
Value is clamped to the range [10 .. 1000].
0 = disabled.
primary_domain: Option<String>Specifies a list of CPUs to prioritize.
Accepts a comma-separated list of CPUs or ranges (i.e., 0-3,12-15) or the following special keywords:
“turbo” = automatically detect and prioritize the CPUs with the highest max frequency, “performance” = automatically detect and prioritize the fastest CPUs, “powersave” = automatically detect and prioritize the slowest CPUs, “all” = all CPUs assigned to the primary domain.
By default “all” CPUs are used.
preferred_idle_scan: boolEnable preferred idle CPU scanning.
With this option enabled, the scheduler will prioritize assigning tasks to higher-ranked cores before considering lower-ranked ones.
stats: Option<f64>Enable stats monitoring with the specified interval.
monitor: Option<f64>Run in stats monitoring mode with the specified interval. Scheduler is not launched.
verbose: boolEnable verbose output, including libbpf details.
version: boolPrint scheduler version and exit.
help_stats: boolShow descriptions for statistics.
libbpf: LibbpfOptsTrait Implementations
Sourceimpl Args for Opts
impl Args for Opts
Sourcefn group_id() -> Option<Id>
fn group_id() -> Option<Id>
ArgGroup::id][crate::ArgGroup::id] for this set of argumentsSourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Command] so it can instantiate self via
[FromArgMatches::update_from_arg_matches_mut] Read moreSourceimpl FromArgMatches for Opts
impl FromArgMatches for Opts
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourceimpl Parser for Opts
impl Parser for Opts
fn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)
fn try_update_from<I, T>(&mut self, itr: I) -> Result<(), Error>
fn try_update_from<I, T>(&mut self, itr: I) -> Result<(), Error>